@@ -522,6 +522,7 @@ class TestInfo:
         expected = ArrayInfo(
             _zarr_format=2,
             _data_type=np.dtype("float64"),
+            _fill_value=arr.fill_value,
             _shape=(8, 8),
             _chunk_shape=chunks,
             _shard_shape=None,
@@ -539,6 +540,7 @@ class TestInfo:
         expected = ArrayInfo(
             _zarr_format=3,
             _data_type=DataType.parse("float64"),
+            _fill_value=arr.fill_value,
             _shape=(8, 8),
             _chunk_shape=chunks,
             _shard_shape=shards,
@@ -564,6 +566,7 @@ class TestInfo:
         expected = ArrayInfo(
             _zarr_format=3,
             _data_type=DataType.parse("float64"),
+            _fill_value=arr.fill_value,
             _shape=(8, 8),
             _chunk_shape=chunks,
             _shard_shape=shards,
@@ -599,6 +602,7 @@ class TestInfo:
         expected = ArrayInfo(
             _zarr_format=2,
             _data_type=np.dtype("float64"),
+            _fill_value=arr.metadata.fill_value,
             _shape=(8, 8),
             _chunk_shape=(2, 2),
             _shard_shape=None,
@@ -624,6 +628,7 @@ class TestInfo:
         expected = ArrayInfo(
             _zarr_format=3,
             _data_type=DataType.parse("float64"),
+            _fill_value=arr.metadata.fill_value,
             _shape=(8, 8),
             _chunk_shape=chunks,
             _shard_shape=shards,
@@ -651,6 +656,7 @@ class TestInfo:
         expected = ArrayInfo(
             _zarr_format=3,
             _data_type=DataType.parse("float64"),
+            _fill_value=arr.metadata.fill_value,
             _shape=(8, 8),
             _chunk_shape=chunks,
             _shard_shape=shards,
@@ -1239,7 +1245,7 @@ class TestCreateArray:
             zarr.create(store=store, dtype="uint8", shape=(10,), zarr_format=3, **kwargs)
 
     @staticmethod
-    @pytest.mark.parametrize("dtype", ["uint8", "float32", "str"])
+    @pytest.mark.parametrize("dtype", ["uint8", "float32", "str", "U10", "S10", ">M8[10s]"])
     @pytest.mark.parametrize(
         "compressors",
         [
@@ -1473,7 +1479,7 @@ class TestCreateArray:
             for parent_path in parents:
                 # this will raise if these groups were not created
                 _ = await zarr.api.asynchronous.open_group(
-                    store=store, path=parent_path, mode="r", zarr_format=zarr_format
+                    store=store, path=parent_path, zarr_format=zarr_format
                 )
 
 
@@ -1661,7 +1667,7 @@ def test_roundtrip_numcodecs() -> None:
 
     BYTES_CODEC = {"name": "bytes", "configuration": {"endian": "little"}}
     # Read in the array again and check compressor config
-    root = zarr.open_group(store, mode="r")
+    root = zarr.open_group(store)
     metadata = root["test"].metadata.to_dict()
     expected = (*filters, BYTES_CODEC, *compressors)
     assert metadata["codecs"] == expected
